<?php
/**
 * The header for UMCTHEME3
 *
 * @package umctheme3
 */

?>
<!doctype html>
<html <?php language_attributes(); ?>>

<head>
    <meta charset="<?php bloginfo( 'charset' ); ?>">
    <meta name="viewport" content="width=device-width, initial-scale=1">
    <link rel="profile" href="https://gmpg.org/xfn/11">
    <link rel="apple-touch-icon" sizes="180x180" href="<?php echo get_template_directory_uri(); ?>/apple-touch-icon.png">
    <link rel="icon" type="image/png" sizes="32x32" href="<?php echo get_template_directory_uri(); ?>/favicon-32x32.png">
    <link rel="icon" type="image/png" sizes="16x16" href="<?php echo get_template_directory_uri(); ?>/favicon-16x16.png">
    <link rel="manifest" href="<?php echo get_template_directory_uri(); ?>/site.webmanifest">
    <link rel="mask-icon" href="<?php echo get_template_directory_uri(); ?>/safari-pinned-tab.svg" color="#cc0000">

    <!-- ANALYTICS -->
    <?php include get_theme_file_path('inc/tracking.php'); ?>
    <!-- END ANALYTICS -->

    <!-- META/OG TAGS -->
    <?php include get_theme_file_path('inc/meta.php'); ?>
    <!-- END META/OG TAGS -->

    <!-- WP HEAD -->
    <?php wp_head(); ?>
    <!-- END WP HEAD -->

</head>

<body <?php body_class('uu-body'); ?>>
    <!-- WP BODY OPEN -->
    <?php wp_body_open(); ?>
    <!-- END WP BODY OPEN -->

    <!-- BODY TRACKING CODE -->
    <?php include get_theme_file_path('inc/tracking-body.php'); ?>
    <!-- END BODY TRACKING CODE -->

    <!-- SIDE NAV -->
    <?php include get_theme_file_path('inc/sidenav.php'); ?>
    <!-- END SIDE NAV -->

    <!-- SEARCH -->
    <?php include get_theme_file_path('inc/search.php'); ?>
    <!-- END SEARCH -->

    <!-- PAGE -->
    <div id="page" class="site uu-page-container">
        <!-- HEADER -->
        <header id="header" class="uu-header fixed">

            <!-- ACCESSIBILITY BAR -->
            <?php //include get_theme_file_path('inc/accessibility-bar.php'); ?>
            <!-- END ACCESSIBILITY BAR -->

            <!-- ALERT BAR -->
            <?php include get_theme_file_path('inc/alert-bar.php'); ?>
            <!-- END ALERT BAR -->

            <div class="uu-bottom-header">
                <!-- HEADER LOGO -->
                <div id="header_logo" class="uu-header-logo">
                    <a href="https://www.utah.edu" aria-label="Visit University of Utah Homepage"></a>
                </div>
                <!-- END HEADER LOGO -->
                <!-- SITE TITLE & DESCRIPTION -->
                <div class="uu-header-title">
                    <?php if ( !empty( get_bloginfo( 'name' ) ) ): ?>
                    <a href="<?php echo esc_url( home_url( '/' ) ); ?>">
                        <?php /*
                            (DEPRECATED: SITE ACRONYM)
                            <?php if ( !empty( get_theme_mod( 'site_acronym' ) ) ): ?>
                            <div class="site-acronym"><?php echo get_theme_mod( 'site_acronym' ); ?></div>
                            <?php endif; ?>
                        */ ?>
                        <h1>
                            <?php echo get_bloginfo( 'name' ); ?>
                            <?php if ( !empty( get_bloginfo( 'description' ) ) ): ?>
                            <span><?php echo get_bloginfo( 'description' ); ?></span>
                            <?php endif; ?>
                        </h1>
                    </a>
                    <?php endif; ?>
                </div>
                <!-- END SITE TITLE & DESCRIPTION -->
                <!-- SEARCH TOGGLE BTN -->
                <div class="uu-search-toggle">
                    <div class="search-btn"><i class="far fa-search"></i></div>
                </div>
                <!-- END SEARCH TOGGLE BTN -->
                <!-- SIDENAV TOGGLE BTN -->
                <div class="uu-sidenav-toggle">
                    <div id="sidenav_toggle_btn" class="hamburger uu-hamburger">
                        <div class="hamburger-box">
                            <div class="hamburger-inner"></div>
                        </div>
                    </div>
                </div>
                <!-- END SIDENAV TOGGLE BTN -->
            </div>
        </header>
        <!-- END HEADER -->
